@@ -65,9 +65,6 @@ class Scheduler(object):
     def from_crawler(cls, crawler):
         instance = cls.from_settings(crawler.settings)
         instance.stats = crawler.stats
-        # idle_number = crawler.settings.getint('IDLE_NUMBER', 360)
-        # ext = cls(idle_number, crawler)
-        # crawler.signals.connect(ext.spider_idle, signal=signals.spider_idle)
         return instance
 
     def open(self, spider):
@@ -103,6 +100,7 @@ class Scheduler(object):
                 spider=spider,
                 topic=[self.settings.get('SPIDER_TOPIC' ,self.topic.format(self.spider.name))],
                 serializer=self.serializer,
+                server=self.server
             )
         except TypeError as e:
             raise ValueError("Failed to instantiate queue class '%s': %s",
@@ -131,26 +129,3 @@ class Scheduler(object):
 
     def has_pending_requests(self):
         return False
-
-    def spider_idle(self):
-        if isinstance(self.queue.partition, int):
-            self._consume_offset = self.queue.consumer.get_watermark_offsets(
-                partition=TopicPartition(topic=defaults.KAFKA_DEFAULTS_TOPIC,
-                                         partition=self.queue.partition))[1]
-            if self.consume_offset == self._consume_offset:
-                self.check_times += 1
-                if self.check_times >= 2:
-                    self.server.set(self.spider.name, self.check_times)
-            else:
-                self.consume_offset = self._consume_offset
-        elif isinstance(self.queue.partition, list):
-            self._consumers_offset = []
-            for partition in self.queue.partition:
-                self._consumers_offset.append(self.queue.consumer.get_watermark_offsets(
-                    partition=TopicPartition(topic=defaults.KAFKA_DEFAULTS_TOPIC, partition=partition))[1])
-            if self.consumers_offset == self._consumers_offset:
-                self.check_times += 1
-                if self.check_times >= 2:
-                    self.server.set(self.spider.name, self.check_times)
-            else:
-                self.consumers_offset = self._consumers_offset
